@@ -52,6 +52,8 @@ while (<ARGV>) {
 	if (defined $translator_comment) {
 	    if (exists $comment{$msgno} && $comment{$msgno} ne $translator_comment) {
 		print STDERR "Different TRANSLATOR comments for message #$msgno\n";
+		print STDERR "survex.pot: $comment{$msgno}\n";
+		print STDERR "$ARGV:$.: $translator_comment\n";
 	    }
 	    $comment{$msgno} = $translator_comment;
 	    undef $translator_comment;
@@ -117,12 +119,16 @@ foreach my $po_entry (@{$num_list}) {
 	    my $fake_err = ": Comment for message #$msgno not in source code\n";
 	    if ($msgno ne '' && exists($uses[$msgno])) {
 		print STDERR join($fake_err, @{$uses[$msgno]}), $fake_err if exists($uses[$msgno]);
+		my $x = $po_entry->automatic;
+		$x =~ s/\n/\n     * /g;
+		print STDERR "    /* $x */\n";
 	    } else {
-		print STDERR $fake_err;
+		# Currently unused message.
+		# print STDERR $fake_err;
+		# my $x = $po_entry->automatic;
+		# $x =~ s/\n/\n     * /g;
+		# print STDERR "    /* $x */\n";
 	    }
-	    my $x = $po_entry->automatic;
-	    $x =~ s/\n/\n     * /g;
-	    print STDERR "    /* $x */\n";
 	}
 	my $automatic = "\n" . $po_entry->automatic;
 	$automatic =~ s/\n/\n#. /g;
