@@ -1,6 +1,6 @@
 /* cavern.h
  * SURVEX Cave surveying software - header file
- * Copyright (C) 1991-2003,2005,2006,2010,2013 Olly Betts
+ * Copyright (C) 1991-2003,2005,2006,2010,2013,2014 Olly Betts
  * Copyright (C) 2004 Simeon Warner
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,8 @@
 #include <math.h>
 #include <float.h>
 
+#include <proj_api.h>
+
 #include "img_hosted.h"
 #include "useful.h"
 
@@ -311,7 +313,7 @@ typedef struct Settings {
    enum {OFF, LOWER, UPPER} Case;
    int style;
    prefix *Prefix;
-   prefix *tag; /* used to check BEGIN/END tags match */
+   prefix *begin_survey; /* used to check BEGIN and END match */
    short *Translate; /* if short is >= 16 bits, which ANSI requires */
    real Var[Q_MAC];
    real z[Q_MAC];
@@ -320,6 +322,7 @@ typedef struct Settings {
    reading *ordering;
    int begin_lineno; /* 0 means no block started in this file */
    int flags;
+   projPJ proj;
    meta_data * meta;
 } settings;
 
@@ -329,6 +332,8 @@ extern prefix *root;
 extern prefix *anon_list;
 extern node *stnlist;
 extern unsigned long optimize;
+extern projPJ proj_out;
+extern char * proj_str_out;
 
 extern char *survey_title;
 extern int survey_title_len;
