@@ -1685,9 +1685,8 @@ cmd_cs(void)
 	 ok_for_output = MAYBE;
 	 if (ch == ':' && isdigit(nextch())) {
 	    unsigned n = read_uint();
-	    if (n < 32768) {
+	    if (n < 1000000) {
 	       cs_sub = (int)n;
-	       /* FIXME: Implement */
 	    }
 	 }
 	 break;
@@ -1719,7 +1718,7 @@ cmd_cs(void)
 	    nextch();
 	    get_token_no_blanks();
 	    cs_class cs2 = match_tok(cs_tab, TABSIZE(cs_tab));
-	    if ((cs ^ CS_LAT) == (cs2 ^ CS_LONG)) {
+	    if ((cs ^ cs2) == (CS_LAT ^ CS_LONG)) {
 		cs_sub = 0;
 	    }
 	 }
@@ -1733,16 +1732,24 @@ cmd_cs(void)
 	    if (strchr("HNOST", uch1)) {
 	       int uch2 = toupper(nextch());
 	       if (uch2 >= 'A' && uch2 <= 'Z' && uch2 != 'I') {
+		  int x, y;
 		  nextch();
+		  if (uch1 > 'I') --uch1;
+		  uch1 -= 'A';
 		  if (uch2 > 'I') --uch2;
-		  cs_sub = (uch1 - 'A') * 25 + (uch2 - 'A');
+		  uch2 -= 'A';
+		  x = uch1 % 5;
+		  y = uch1 / 5;
+		  x = (x * 5) + uch2 % 5;
+		  y = (y * 5) + uch2 / 5;
+		  cs_sub = y * 25 + x;
 	       }
 	    }
 	 }
 	 break;
       case CS_S_MERC:
-         /* FIXME: Is this ok_for_output? */
 	 if (ch == '-') {
+	    nextch();
 	    get_token_no_blanks();
 	    if (strcmp(ucbuffer, "MERC") == 0) {
 	       cs_sub = 0;
@@ -1772,34 +1779,80 @@ cmd_cs(void)
    }
    /* Actually handle the cs */
    switch (cs) {
+      case CS_NONE:
+	 break;
       case CS_CUSTOM:
+	 /* proj_str already set */
 	 break;
       case CS_EPSG:
+	 proj_str = osmalloc(32);
+	 sprintf(proj_str, "+init=epsg:%d +no_defs", cs_sub);
+	 break;
       case CS_ESRI:
+	 proj_str = osmalloc(32);
+	 sprintf(proj_str, "+init=esri:%d +no_defs", cs_sub);
+	 break;
       case CS_EUR:
+	 proj_str = osstrdup("+proj=utm +zone=30 +ellps=intl +towgs84=-86,-98,-119,0,0,0,0 +no_defs");
+	 break;
       case CS_IJTSK:
+	 if (cs_sub == 0)
+	    proj_str = osstrdup("+proj=krovak +ellps=bessel +towgs84=570.8285,85.6769,462.842,4.9984,1.5867,5.2611,3.5623 +no_defs");
+	 else
+	    proj_str = osstrdup("+proj=krovak +ellps=bessel +towgs84=485.021,169.465,483.839,7.786342,4.397554,4.102655,0 +no_defs");
+	 break;
       case CS_JTSK:
+	 if (cs_sub == 0)
+	    proj_str = osstrdup("+proj=krovak +czech +ellps=bessel +towgs84=570.8285,85.6769,462.842,4.9984,1.5867,5.2611,3.5623 +no_defs");
+	 else
+	    proj_str = osstrdup("+proj=krovak +czech +ellps=bessel +towgs84=485.021,169.465,483.839,7.786342,4.397554,4.102655,0 +no_defs");
+	 break;
       case CS_LAT:
+	 /* FIXME: Requires PROJ >= 4.8.0 for +axis, and the SDs will be
+	  * misapplied, so we may want to swap ourselves.  Also, while
+	  * therion supports lat-long, I'm not totally convinced that it is
+	  * sensible to do so - people often say "lat-long", but probably
+	  * don't think that that's actually "Northing, Easting".  This
+	  * seems like it'll result in people accidentally getting X and Y
+	  * swapped in their fixed points...
+	  */
+#if 0
+	 proj_str = osstrdup("+proj=longlat +ellps=WGS84 +datum=WGS84 +axis=neu +no_defs");
+#endif
+	 break;
       case CS_LOCAL:
+	 /* FIXME: Is it useful to be able to explicitly specify this? */
+	 break;
       case CS_LONG:
-      case CS_OSGB:
+	 proj_str = osstrdup("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
+	 break;
+      case CS_OSGB: {
+	 int x = 14 - (cs_sub % 25);
+	 int y = (cs_sub / 25) - 20;
+	 proj_str = osmalloc(160);
+	 sprintf(proj_str, "+proj=tmerc +lat_0=49 +lon_0=-2 +k=0.9996012717 +x_0=%d +y_0=%d +ellps=airy +datum=OSGB36 +units=m +no_defs", x * 100000, y * 100000);
+	 break;
+      }
       case CS_S_MERC:
-      default:
-	 /* FIXME: Handle these too... */
-	 /* printf("CS %d:%d\n", (int)cs, cs_sub); */
-	 set_pos(&fp);
-	 compile_error_skip(-/*Unknown coordinate system*/434);
-	 return;
+	 proj_str = osstrdup("+proj=merc +lat_ts=0 +lon_0=0 +k=1 +x_0=0 +y_0=0 +a=6378137 +b=6378137 +units=m +nadgrids=@null +no_defs");
+	 break;
       case CS_UTM:
-	 proj_str = osmalloc(64);
+	 proj_str = osmalloc(74);
 	 if (cs_sub > 0) {
-	    sprintf(proj_str, "+proj=utm +ellps=WGS84 +datum=WGS84 +units=m +zone=%d", cs_sub);
+	    sprintf(proj_str, "+proj=utm +ellps=WGS84 +datum=WGS84 +units=m +zone=%d +no_defs", cs_sub);
 	 } else {
-	    sprintf(proj_str, "+proj=utm +ellps=WGS84 +datum=WGS84 +units=m +zone=%d +south", -cs_sub);
+	    sprintf(proj_str, "+proj=utm +ellps=WGS84 +datum=WGS84 +units=m +zone=%d +south +no_defs", -cs_sub);
 	 }
 	 break;
    }
 
+   if (!proj_str) {
+      /* printf("CS %d:%d\n", (int)cs, cs_sub); */
+      set_pos(&fp);
+      compile_error_skip(-/*Unknown coordinate system*/434);
+      return;
+   }
+
    if (output) {
       if (ok_for_output == NO) {
 	 set_pos(&fp);
