@@ -396,7 +396,7 @@ data_file(const char *pth, const char *fnm)
       }
 
       if (fh == NULL) {
-	 compile_error(/*Couldn’t open data file “%s”*/24, fnm);
+	 compile_error(/*Couldn’t open file “%s”*/24, fnm);
 	 return;
       }
 
@@ -845,7 +845,7 @@ warn_readings_differ(int msgno, real diff)
       while (*++p) {
 	 if (*p != '0') z = p + 1;
       }
-      if (*z) *z = '\0';
+      *z = '\0';
    }
    compile_warning(msgno, buf);
 }
