@@ -33,6 +33,7 @@
 #include "exportfilter.h"
 #include "gpx.h"
 #include "hpgl.h"
+#include "kml.h"
 #include "mainfrm.h"
 
 #include <float.h>
@@ -1161,6 +1162,10 @@ Export(const wxString &fnm_out, const wxString &title,
 	   filt = new HPGL;
 	   // factor = POINTS_PER_MM * 1000.0 / scale;
 	   break;
+       case FMT_KML:
+	   filt = new KML(input_projection);
+	   show_mask |= FULL_COORDS;
+	   break;
        case FMT_PLT:
 	   filt = new PLT;
 	   show_mask |= FULL_COORDS;
@@ -1391,15 +1396,16 @@ Export(const wxString &fnm_out, const wxString &title,
 	      } else if (pass_mask & LABELS) {
 		  type = LABELS;
 	      }
+	      /* Use !UNDERGROUND as the criterion - we want stations where a
+	       * surface and underground survey meet to be in the underground
+	       * layer */
+	      bool f_surface = !(*pos)->IsUnderground();
 	      if (type) {
-		  const char * text = (*pos)->GetText().mb_str();
-		  /* Use !UNDERGROUND as the criterion - we want stations where
-		   * a surface and underground survey meet to be in the
-		   * underground layer */
-		  filt->label(&p, text, !(*pos)->IsUnderground(), type);
+		  const wxString & text = (*pos)->GetText();
+		  filt->label(&p, text.mb_str(), f_surface, type);
 	      }
 	      if (pass_mask & STNS)
-		  filt->cross(&p, !(*pos)->IsUnderground());
+		  filt->cross(&p, f_surface);
 	  }
       }
       if (pass_mask & (XSECT|WALLS|PASG)) {
