@@ -30,6 +30,15 @@
 #include "useful.h"
 #include "wx.h"
 
+#include <cerrno>
+#ifdef HAVE_MMAP
+#include <sys/mman.h>
+#else
+#include <unistd.h>
+#endif
+
+using namespace std;
+
 #include "../lib/preload_font.h"
 
 #define CHECK_GL_ERROR(M, F) do { \
@@ -65,7 +74,7 @@ BitmapFont::load(const wxString & font_file_)
 	byte_width >>= 6;
 
 	int start = 0;
-	int n = 0;
+	unsigned int n = 0;
 	if (byte_width) {
 	    if (p == end) {
 		return false;
@@ -74,7 +83,7 @@ BitmapFont::load(const wxString & font_file_)
 	    start = start_and_n >> 4;
 	    n = (start_and_n & 15) + 1;
 
-	    if (end - p < n * byte_width) {
+	    if (unsigned(end - p) < n * byte_width) {
 		return false;
 	    }
 	}
@@ -109,43 +118,69 @@ void
 BitmapFont::init_extra_chars() const
 {
 #ifdef __WXMSW__
-    FILE * fh = _wfopen(font_file.fn_str(), L"rb");
+    int fd = _wopen(font_file.fn_str(), _O_RDONLY|_O_SEQUENTIAL);
 #else
-    FILE * fh = fopen(font_file.mb_str(), "rb");
+    int fd = open(font_file.mb_str(), O_RDONLY);
 #endif
 
-    long data_len = 0;
-    if (fh && fseek(fh, 0, SEEK_END) >= 0) {
-	data_len = ftell(fh);
-	if (data_len == -1)
-	    data_len = 0;
+    int data_len = 0;
+    unsigned char * data = NULL;
+    if (fd >= 0) {
+	struct stat sb;
+	if (fstat(fd, &sb) >= 0) {
+	    data_len = sb.st_size;
+	}
     }
-    unsigned char * data = new unsigned char [data_len];
-    if (data_len && (fseek(fh, 0, SEEK_SET) < 0 ||
-	       fread(data, data_len, 1, fh) != 1)) {
-	data_len = 0;
-	// FIXME: do something better.  wxGetApp().ReportError(m);
-	// We have this message available: Error in format of font file “%s”
-	// fprintf(stderr, "Couldn't load extended font.\n");
-    }
-    if (fh)
-	fclose(fh);
 
-    extra_chars = new unsigned char * [0x10000 - BITMAPFONT_MAX_CHAR];
+#if HAVE_MMAP
+    if (data_len) {
+	void * p = mmap(NULL, data_len, PROT_READ, MAP_SHARED, fd, 0);
+	if (p == MAP_FAILED) {
+	    data_len = 0;
+	} else {
+	    extra_data = data = static_cast<unsigned char*>(p);
+	}
+    }
+#else
+    data = new unsigned char [data_len];
+    extra_data = data;
+    if (data_len) {
+	size_t c = data_len;
+	unsigned char * p = data;
+	while (c) {
+	    ssize_t n = read(fd, p, c);
+	    if (n <= 0) {
+		if (errno == EINTR) continue;
+		data_len = 0;
+		// FIXME: do something better.  wxGetApp().ReportError(m);
+		// We have this message available: Error in format of font file “%s”
+		// fprintf(stderr, "Couldn't load extended font.\n");
+		break;
+	    }
+	    p += n;
+	    c -= n;
+	}
+    }
+#endif
+
+    if (fd >= 0)
+	close(fd);
+
+    extra_chars = new int [0x10000 - BITMAPFONT_MAX_CHAR];
+    int data_ch = 0;
     for (int i = 0; i < 0x10000 - BITMAPFONT_MAX_CHAR; ++i) {
-	if (data_len <= 0) {
-	    extra_chars[i] = NULL;
+	if (data_ch >= data_len) {
+	    extra_chars[i] = -1;
 	    continue;
 	}
-	extra_chars[i] = data;
-	unsigned int byte_width = *data++;
+	extra_chars[i] = data_ch;
+	unsigned int byte_width = data[data_ch++];
 	byte_width >>= 6;
 
 	if (byte_width) {
-	    unsigned int start_and_n = *data;
+	    unsigned int start_and_n = data[data_ch];
 	    int n = (start_and_n & 15) + 1;
-	    data += n * byte_width + 1;
-	    data_len -= n * byte_width + 1;
+	    data_ch += n * byte_width + 1;
 	}
     }
 }
@@ -161,9 +196,9 @@ BitmapFont::glyph_width(wxChar ch) const
 
     int width = 8;
 
-    const unsigned char * p = extra_chars[ch - BITMAPFONT_MAX_CHAR];
-    if (p) {
-	unsigned int byte_width = *p;
+    int char_idx = extra_chars[ch - BITMAPFONT_MAX_CHAR];
+    if (char_idx >= 0) {
+	unsigned int byte_width = extra_data[char_idx];
 	width = (byte_width & 0x0f) + 2;
     }
 
@@ -184,8 +219,10 @@ BitmapFont::write_glyph(wxChar ch) const
     int n = 0;
     int width = 8;
 
-    const unsigned char * p = extra_chars[ch - BITMAPFONT_MAX_CHAR];
-    if (p) {
+    int char_idx = extra_chars[ch - BITMAPFONT_MAX_CHAR];
+    const unsigned char * p = extra_data;
+    if (char_idx >= 0) {
+	p += char_idx;
 	byte_width = *p++;
 	width = (byte_width & 0x0f) + 2;
 	byte_width >>= 6;
