@@ -159,7 +159,6 @@ public:
 	SetAutoLayout(true);
 	SetSizer(vert);
 
-	vert->Fit(this);
 	vert->SetSizeHints(this);
     }
     PresentationMark GetMark() const {
@@ -385,7 +384,7 @@ class AvenPresList : public wxListCtrl {
 #endif
 	    if (!fh_pres) {
 		wxString m;
-		m.Printf(wmsg(/*Couldn’t open file “%s”*/93), fnm.c_str());
+		m.Printf(wmsg(/*Couldn’t open file “%s”*/24), fnm.c_str());
 		wxGetApp().ReportError(m);
 		return false;
 	    }
@@ -703,7 +702,7 @@ MainFrm::MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size)
     m_NumHighlighted(0),
     m_HasUndergroundLegs(false), m_HasSplays(false), m_HasSurfaceLegs(false),
     m_HasErrorInformation(false), m_IsExtendedElevation(false),
-    pending_find(false)
+    pending_find(false), fullscreen_showing_menus(false)
 #ifdef PREFDLG
     , m_PrefsDlg(NULL)
 #endif
@@ -721,8 +720,13 @@ MainFrm::MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size)
     SetIcon(wxIcon(icon_path + APP_IMAGE, wxBITMAP_TYPE_PNG));
 #endif
 
+#if wxCHECK_VERSION(3,1,0)
+    // Add a full screen button to the right upper corner of title bar under OS
+    // X 10.7 and later.
+    EnableFullScreenView();
+#endif
     CreateMenuBar();
-    CreateToolBar();
+    MakeToolBar();
     CreateStatusBar(2, wxST_SIZEGRIP);
     CreateSidePanel();
 
@@ -943,9 +947,9 @@ void MainFrm::CreateMenuBar()
 // ICON must be a literal string.
 #define TOOLBAR_BITMAP(ICON) wxBitmap(icon_path + wxT(ICON".png"), wxBITMAP_TYPE_PNG)
 
-void MainFrm::CreateToolBar()
+void MainFrm::MakeToolBar()
 {
-    // Create the toolbar.
+    // Make the toolbar.
 
     wxToolBar* toolbar = wxFrame::CreateToolBar();
 
@@ -1012,7 +1016,6 @@ void MainFrm::CreateSidePanel()
     panel_sizer->Add(m_Tree, 1, wxALL | wxEXPAND, 2);
     panel->SetAutoLayout(true);
     panel->SetSizer(panel_sizer);
-//    panel_sizer->Fit(panel);
 //    panel_sizer->SetSizeHints(panel);
 
     m_Control = new GUIControl();
@@ -2017,7 +2020,7 @@ void MainFrm::ClearTreeSelection()
 {
     m_Tree->UnselectAll();
     m_Gfx->SetThere();
-    ShowInfo(NULL);
+    ShowInfo();
 }
 
 void MainFrm::ClearCoords()
@@ -2062,7 +2065,7 @@ const LabelInfo * MainFrm::GetTreeSelection() const {
     return data->GetLabel();
 }
 
-void MainFrm::SetCoords(Double x, Double y)
+void MainFrm::SetCoords(Double x, Double y, const LabelInfo * there)
 {
     wxString & s = coords_text;
     if (m_Gfx->GetMetric()) {
@@ -2074,10 +2077,9 @@ void MainFrm::SetCoords(Double x, Double y)
 
     wxString & t = distfree_text;
     t = wxString();
-    const LabelInfo* label;
-    if (m_Gfx->ShowingMeasuringLine() && (label = GetTreeSelection())) {
-	Vector3 delta(x - m_Offsets.GetX() - label->GetX(),
-		      y - m_Offsets.GetY() - label->GetY(), 0);
+    if (m_Gfx->ShowingMeasuringLine() && there) {
+	Vector3 delta(x - m_Offsets.GetX() - there->GetX(),
+		      y - m_Offsets.GetY() - there->GetY(), 0);
 	Double dh = sqrt(delta.GetX()*delta.GetX() + delta.GetY()*delta.GetY());
 	Double brg = deg(atan2(delta.GetX(), delta.GetY()));
 	if (brg < 0) brg += 360;
@@ -2087,8 +2089,7 @@ void MainFrm::SetCoords(Double x, Double y)
 	 * From <stationname>
 	 * H: 123.45m V: 234.56m
 	 * Dist: 456.78m  Brg: 200 */
-	from_str.Printf(wmsg(/*From %s*/339), label->GetText().c_str());
-
+	from_str.Printf(wmsg(/*From %s*/339), there->name_or_anon());
 	int brg_unit;
 	if (m_Gfx->GetDegrees()) {
 	    brg_unit = /*°*/344;
@@ -2119,7 +2120,7 @@ void MainFrm::SetCoords(Double x, Double y)
     UpdateStatusBar();
 }
 
-void MainFrm::SetAltitude(Double z)
+void MainFrm::SetAltitude(Double z, const LabelInfo * there)
 {
     double alt = z;
     int units;
@@ -2134,12 +2135,11 @@ void MainFrm::SetAltitude(Double z)
 
     wxString & t = distfree_text;
     t = wxString();
-    const LabelInfo* label;
-    if (m_Gfx->ShowingMeasuringLine() && (label = GetTreeSelection())) {
-	Double dz = z - m_Offsets.GetZ() - label->GetZ();
+    if (m_Gfx->ShowingMeasuringLine() && there) {
+	Double dz = z - m_Offsets.GetZ() - there->GetZ();
 
 	wxString from_str;
-	from_str.Printf(wmsg(/*From %s*/339), label->GetText().c_str());
+	from_str.Printf(wmsg(/*From %s*/339), there->name_or_anon());
 
 	if (!m_Gfx->GetMetric()) {
 	    dz /= METRES_PER_FOOT;
@@ -2152,7 +2152,7 @@ void MainFrm::SetAltitude(Double z)
     UpdateStatusBar();
 }
 
-void MainFrm::ShowInfo(const LabelInfo *here)
+void MainFrm::ShowInfo(const LabelInfo *here, const LabelInfo *there)
 {
     assert(m_Gfx);
 
@@ -2185,13 +2185,12 @@ void MainFrm::ShowInfo(const LabelInfo *here)
     s += wxString::Format(wxT(", %s %.2f%s"), wmsg(/*Altitude*/335).c_str(),
 			  z, wmsg(units).c_str());
     s += wxT(": ");
-    s += here->GetText();
-    m_Gfx->SetHere(*here);
+    s += here->name_or_anon();
+    m_Gfx->SetHere(here);
     m_Tree->SetHere(here->tree_id);
 
-    const LabelInfo* label;
-    if (m_Gfx->ShowingMeasuringLine() && (label = GetTreeSelection())) {
-	Vector3 delta = *here - *label;
+    if (m_Gfx->ShowingMeasuringLine() && there) {
+	Vector3 delta = *here - *there;
 
 	Double d_horiz = sqrt(delta.GetX()*delta.GetX() +
 			      delta.GetY()*delta.GetY());
@@ -2202,7 +2201,7 @@ void MainFrm::ShowInfo(const LabelInfo *here)
 	if (brg < 0) brg += 360;
 
 	wxString from_str;
-	from_str.Printf(wmsg(/*From %s*/339), label->GetText().c_str());
+	from_str.Printf(wmsg(/*From %s*/339), there->name_or_anon());
 
 	wxString hv_str;
 	if (m_Gfx->GetMetric()) {
@@ -2230,7 +2229,6 @@ void MainFrm::ShowInfo(const LabelInfo *here)
 	d.Printf(wmsg(/*%s: %s, Dist %.2f%s, Brg %03d%s*/341),
 		 from_str.c_str(), hv_str.c_str(),
 		 dr, len_unit.c_str(), int(brg), wmsg(brg_unit).c_str());
-	m_Gfx->SetThere(*label);
     } else {
 	dist_text = wxString();
 	m_Gfx->SetThere();
@@ -2242,11 +2240,9 @@ void MainFrm::DisplayTreeInfo(const wxTreeItemData* item)
 {
     const TreeData* data = static_cast<const TreeData*>(item);
     if (data && data->IsStation()) {
-	const LabelInfo * label = data->GetLabel();
-	ShowInfo(label);
-	m_Gfx->SetHere(*label);
+	m_Gfx->SetHereFromTree(data->GetLabel());
     } else {
-	ShowInfo(NULL);
+	ShowInfo();
     }
 }
 
@@ -2256,7 +2252,7 @@ void MainFrm::TreeItemSelected(const wxTreeItemData* item, bool zoom)
     if (data && data->IsStation()) {
 	const LabelInfo* label = data->GetLabel();
 	if (zoom) m_Gfx->CentreOn(*label);
-	m_Gfx->SetThere(*label);
+	m_Gfx->SetThere(label);
 	dist_text = wxString();
 	// FIXME: Need to update dist_text (From ... etc)
 	// But we don't currently know where "here" is at this point in the
@@ -2690,8 +2686,29 @@ bool MainFrm::ShowingSidePanel()
 
 void MainFrm::ViewFullScreen() {
     ShowFullScreen(!IsFullScreen());
+    fullscreen_showing_menus = false;
     if (IsFullScreen())
 	was_showing_sidepanel_before_fullscreen = ShowingSidePanel();
     if (was_showing_sidepanel_before_fullscreen)
 	ToggleSidePanel();
 }
+
+bool MainFrm::FullScreenModeShowingMenus() const
+{
+    return fullscreen_showing_menus;
+}
+
+void MainFrm::FullScreenModeShowMenus(bool show)
+{
+    if (!IsFullScreen() || show == fullscreen_showing_menus)
+	return;
+    Freeze();
+    ShowFullScreen(false);
+    if (show) {
+	ShowFullScreen(true, wxFULLSCREEN_ALL ^ wxFULLSCREEN_NOMENUBAR);
+    } else {
+	ShowFullScreen(true);
+    }
+    Thaw();
+    fullscreen_showing_menus = show;
+}
