@@ -96,43 +96,50 @@ solve_network(void /*node *stnlist*/)
    ptrTrail = NULL;
    dump_network();
 
-   /* If there are no fixed points, invent one.  Do this first to
-    * avoid problems with sub-nodes of the invented fix which have
-    * been removed.  It also means we can fix the "first" station,
-    * which makes more sense to the user. */
-   FOR_EACH_STN(stn, stnlist)
-      if (fixed(stn)) break;
+   if (first_solve && !pcs->proj && !proj_out) {
+      /* If we haven't already solved to find some station positions, and
+       * there's no specified coordinate system, then check if there are any
+       * fixed points, and if there aren't, invent one at (0,0,0).
+       *
+       * We do this first so the solving part is just like the standard case -
+       * this avoid problems, such as sub-nodes of the invented fix having been
+       * removed.  It also means we can fix the "first" station, which makes
+       * more sense to the user. */
+      FOR_EACH_STN(stn, stnlist)
+	 if (fixed(stn)) break;
 
-   if (!stn && first_solve) {
-     /* If we've had a *solve and all the new survey since then is hanging,
-      * we don't want to invent a fixed point.  We want to complain but
-      * the easiest way to is just to continue processing and let
-      * articulate() catch this condition as it will any hanging survey
-      * data. */
-      node *stnFirst = NULL;
+      if (!stn) {
+	/* If we've had a *solve and all the new survey since then is hanging,
+	 * we don't want to invent a fixed point.  We want to complain but
+	 * the easiest way to is just to continue processing and let
+	 * articulate() catch this condition as it will any hanging survey
+	 * data. */
+	 node *stnFirst = NULL;
 
-      /* New stations are pushed onto the head of the list, so the
-       * first station added is the last in the list. */
-      FOR_EACH_STN(stn, stnlist) {
-	  /* Prefer a station with legs attached when choosing one to fix
-	   * so that if there's a hanging station on a nosurvey leg we pick
-	   * the main clump of survey data. */
-	  if (stnFirst && !stnFirst->leg[0]) continue;
-	  stnFirst = stn;
+	 /* New stations are pushed onto the head of the list, so the
+	  * first station added is the last in the list. */
+	 FOR_EACH_STN(stn, stnlist) {
+	     /* Prefer a station with legs attached when choosing one to fix
+	      * so that if there's a hanging station on a nosurvey leg we pick
+	      * the main clump of survey data. */
+	     if (stnFirst && !stnFirst->leg[0]) continue;
+	     stnFirst = stn;
+	 }
+
+	 /* If we've got nosurvey legs, then the station we find to fix could
+	  * have no real legs attached. */
+	 SVX_ASSERT2(nosurveyhead || stnFirst->leg[0],
+		     "no fixed stns, but we've got a zero node!");
+	 SVX_ASSERT2(stnFirst, "no stations left in net!");
+	 stn = stnFirst;
+	 printf(msg(/*Survey has no fixed points. Therefore I’ve fixed %s at (0,0,0)*/72),
+		sprint_prefix(stn->name));
+	 putnl();
+	 POS(stn,0) = (real)0.0;
+	 POS(stn,1) = (real)0.0;
+	 POS(stn,2) = (real)0.0;
+	 fix(stn);
       }
-
-      /* If we've got nosurvey legs, then the station we find to fix could have
-       * no real legs attached. */
-      SVX_ASSERT2(nosurveyhead || stnFirst->leg[0], "no fixed stns, but we've got a zero node!");
-      SVX_ASSERT2(stnFirst, "no stations left in net!");
-      stn = stnFirst;
-      printf(msg(/*Survey has no fixed points. Therefore I’ve fixed %s at (0,0,0)*/72),
-	     sprint_prefix(stn->name));
-      putnl();
-      POS(stn,0) = (real)0.0;
-      POS(stn,1) = (real)0.0;
-      POS(stn,2) = (real)0.0;
-      fix(stn);
    }
 
    first_solve = 0;
@@ -160,6 +167,13 @@ static void
 remove_trailing_travs(void)
 {
    node *stn;
+   /* TRANSLATORS: In French, Eric chose to use the terminology used by
+    * toporobot: "sequence" for the English "traverse", which makes sense
+    * (although toporobot actually uses this term to mean something more
+    * specific).  Feel free to follow this lead if you can't think of a better
+    * term - these messages mostly indicate how processing is progressing.
+    * 
+    * A trailing traverse is a dead end back to a junction. */
    out_current_action(msg(/*Removing trailing traverses*/125));
    FOR_EACH_STN(stn, stnlist) {
       if (!fixed(stn) && one_node(stn)) {
@@ -214,6 +228,11 @@ static void
 remove_travs(void)
 {
    node *stn;
+   /* TRANSLATORS: In French, Eric chose to use the terminology used by
+    * toporobot: "sequence" for the English "traverse", which makes sense
+    * (although toporobot actually uses this term to mean something more
+    * specific).  Feel free to follow this lead if you can't think of a better
+    * term - these messages mostly indicate how processing is progressing. */
    out_current_action(msg(/*Concatenating traverses*/126));
    FOR_EACH_STN(stn, stnlist) {
       if (fixed(stn) || three_node(stn)) {
@@ -407,6 +426,11 @@ replace_travs(void)
    int cLegsTrav = 0;
    bool fArtic;
 
+    /* TRANSLATORS: In French, Eric chose to use the terminology used by
+     * toporobot: "sequence" for the English "traverse", which makes sense
+     * (although toporobot actually uses this term to mean something more
+     * specific).  Feel free to follow this lead if you can't think of a better
+     * term - these messages mostly indicate how processing is progressing. */
    out_current_action(msg(/*Calculating traverses*/127));
 
    if (!fhErrStat && !fSuppress)
@@ -415,7 +439,7 @@ replace_travs(void)
    if (!pimg) {
       char *fnm = add_ext(fnm_output_base, EXT_SVX_3D);
       filename_register_output(fnm);
-      pimg = img_open_write(fnm, survey_title, 0);
+      pimg = img_open_write_cs(fnm, survey_title, proj_str_out, 0);
       if (!pimg) fatalerror(img_error(), fnm);
       osfree(fnm);
    }
@@ -719,10 +743,16 @@ err_stat(int cLegsTrav, double lenTrav,
       fputnl(fhErrStat);
       fprintf(fhErrStat, msg(/*Original length %6.2fm (%3d legs), moved %6.2fm (%5.2fm/leg). */145),
 	      lenTrav, cLegsTrav, sqrt_eTot, sqrt_eTot / cLegsTrav);
-      if (lenTrav > 0.0)
+      if (lenTrav > 0.0) {
 	 fprintf(fhErrStat, msg(/*Error %6.2f%%*/146), 100 * sqrt_eTot / lenTrav);
-      else
+      } else {
+	 /* TRANSLATORS: Here N/A means "Not Applicable" -- it means the
+	  * traverse has zero length, so error per metre is meaningless.
+	  *
+	  * There should be 4 spaces between "Error" and "N/A" so that it lines
+	  * up with the numbers in the message above. */
 	 fputs(msg(/*Error    N/A*/147), fhErrStat);
+      }
       fputnl(fhErrStat);
       fprintf(fhErrStat, "%f\n", E);
       fprintf(fhErrStat, "H: %f V: %f\n", H, V);
@@ -739,6 +769,13 @@ replace_trailing_travs(void)
    linkfor *leg;
    int i;
 
+   /* TRANSLATORS: In French, Eric chose to use the terminology used by
+    * toporobot: "sequence" for the English "traverse", which makes sense
+    * (although toporobot actually uses this term to mean something more
+    * specific).  Feel free to follow this lead if you can't think of a better
+    * term - these messages mostly indicate how processing is progressing.
+    * 
+    * A trailing traverse is a dead end back to a junction. */
    out_current_action(msg(/*Calculating trailing traverses*/128));
 
    while (ptrTrail != NULL) {
@@ -915,6 +952,8 @@ replace_trailing_travs(void)
 	    }
 	 }
 	 if (unused_fixed_point) {
+	    /* TRANSLATORS: fixed survey station that is not part of any survey
+	     */
 	    warning_in_file(stn1->name->filename, stn1->name->line,
 		    /*Unused fixed point “%s”*/73, sprint_prefix(stn1->name));
 	 }
@@ -1000,6 +1039,9 @@ write_passage_models(void)
 	 osfree(oldx);
 
 	 if (!pfx->pos) {
+	     /* TRANSLATORS: e.g. the user specifies a passage cross-section at
+	      * station "entrance.27", but there is no station "entrance.27" in
+	      * the centre-line. */
 	     error_in_file(pfx->filename, pfx->line,
 			   /*Cross section specified at non-existent station “%s”*/83,
 			   name);
